@@ -33,23 +33,23 @@ public class CellRendererToggleEvent extends GtkEvent {
 		public static final Type TOGGLED = new Type(1, "TOGGLED");
 	}
 
-	protected String index;
+	protected String path;
 
 	/**
 	 * Creates a new event. This is used internally by java-gnome. Users
 	 * only have to deal with listeners.
 	 */
-	public CellRendererToggleEvent(Object source, String index) {
+	public CellRendererToggleEvent(Object source, String path) {
 		super(source, Type.TOGGLED);
-		this.index = index;
+		this.path = path;
 	}
 	
 	/**
 	 * Returns the TreeIter index of which the text has been changed.
 	 * @return the TreeIter index
 	 */
-	public String getIndex() {
-		return this.index;
+	public String getPath() {
+		return this.path;
 	}
 
 }
